@@ -322,8 +322,8 @@ cb_keypress (GtkWidget *widget, GdkEventKey *event)
 	default:
 		howmuch = 0;
 	}
-	
-	return FALSE;
+
+	return TRUE;
 }
 
 gboolean
@@ -518,6 +518,8 @@ main (gint argc, gchar *argv[])
 	
 	gtk_signal_connect (GTK_OBJECT (window), "delete_event",
 			    GTK_SIGNAL_FUNC (cb_quit), im);
+	gtk_signal_connect (GTK_OBJECT (window), "destroy",
+			    GTK_SIGNAL_FUNC (cb_quit), im);
 	gtk_signal_connect (GTK_OBJECT (window), "key_press_event",
 			    GTK_SIGNAL_FUNC (cb_keypress), NULL);
 
@@ -565,7 +567,7 @@ main (gint argc, gchar *argv[])
 			    TRUE, FALSE, 0);
 
 	gtk_box_pack_start (GTK_BOX (hbox),
-			    gnome_href_new ("http://www.gnome.org/",
+			    gnome_href_new (_("http://www.gnome.org/"),
 					    _("GNOME Main Site")),
 			    TRUE, FALSE, 0);
 
