@@ -765,12 +765,12 @@ make_hidebutton(BasePWidget *basep,
 	GtkWidget *pixmap;
 	char *pixmap_name;
 
-	w=gtk_button_new();
-	GTK_WIDGET_UNSET_FLAGS(w,GTK_CAN_DEFAULT|GTK_CAN_FOCUS);
+	w = gtk_button_new();
+	GTK_WIDGET_UNSET_FLAGS(w, GTK_CAN_DEFAULT|GTK_CAN_FOCUS);
 	if(horizontal)
-		gtk_widget_set_usize(w,0,PANEL_MINIMUM_WIDTH);
+		gtk_widget_set_usize(w, 0, PANEL_MINIMUM_WIDTH);
 	else
-		gtk_widget_set_usize(w,PANEL_MINIMUM_WIDTH,0);
+		gtk_widget_set_usize(w, PANEL_MINIMUM_WIDTH, 0);
 
 	pixmap_name=gnome_pixmap_file(pixmaparrow);
 	if(pixmap_name) {
@@ -1364,12 +1364,12 @@ basep_widget_convert_to (BasePWidget *basep,
 #endif
 
 void
-_basep_widget_enable_buttons(BasePWidget *basep, gboolean enabled)
+basep_widget_enable_buttons_ (BasePWidget *basep, gboolean enabled)
 {
-	gtk_widget_set_sensitive(basep->hidebutton_n,enabled);
-	gtk_widget_set_sensitive(basep->hidebutton_e,enabled);
-	gtk_widget_set_sensitive(basep->hidebutton_w,enabled);
-	gtk_widget_set_sensitive(basep->hidebutton_s,enabled);
+	gtk_widget_set_sensitive(basep->hidebutton_n, enabled);
+	gtk_widget_set_sensitive(basep->hidebutton_e, enabled);
+	gtk_widget_set_sensitive(basep->hidebutton_w, enabled);
+	gtk_widget_set_sensitive(basep->hidebutton_s, enabled);
 }
 
 void
