@@ -180,11 +180,11 @@ drawer_click(GtkWidget *w, Drawer *drawer)
 	switch (BASEP_WIDGET (drawerw)->state) {
 	case BASEP_SHOWN:
 	case BASEP_AUTO_HIDDEN:
-		drawer_widget_close_drawer (drawerw, BASEP_WIDGET (panelw));
+		drawer_widget_close_drawer (drawerw, panelw);
 		break;
 	case BASEP_HIDDEN_LEFT:
 	case BASEP_HIDDEN_RIGHT:
-		drawer_widget_open_drawer (drawerw, BASEP_WIDGET (panelw));
+		drawer_widget_open_drawer (drawerw, panelw);
 		break;
 	case BASEP_MOVING:
 		g_assert_not_reached ();
@@ -198,9 +198,15 @@ destroy_drawer(GtkWidget *widget, gpointer data)
 	Drawer *drawer = data;
 	GtkWidget *prop_dialog = drawer->properties;
 
+	drawer->properties = NULL;
+
 	if(prop_dialog)
 		gtk_widget_destroy(prop_dialog);
-	g_free(drawer);
+
+	/* HACK!, we don't free drawer structure here like other applets.
+	 * it is freed in applet_destroyed in applet.c.  There is a cleaner
+	 * solution in the 1.4 version, but for the stable version this is
+	 * GoodEnough(tm) */
 }
 
 static int
@@ -392,7 +398,8 @@ load_drawer_applet(int mypanel, char *pixmap, char *tooltip,
 				 drawer);
 
 	/* this doesn't make sense anymore */
-	if(BASEP_WIDGET(drawer->drawer)->state == BASEP_SHOWN) {
+	if ((BASEP_WIDGET(drawer->drawer)->state == BASEP_SHOWN) &&
+	    (IS_BASEP_WIDGET (panel->panel_parent))) {
 		/*pop up, if popped down, if it's not an autohidden
 		  widget then it will just ignore this next call */
 		basep_widget_autoshow(BASEP_WIDGET(panel->panel_parent));
