@@ -5,18 +5,18 @@
  *
  */
 
-#ifndef __FOOBAR_WIDGET_H__
-#define __FOOBAR_WIDGET_H__
+#ifndef FOOBAR_WIDGET_H
+#define FOOBAR_WIDGET_H
 
 #include <gnome.h>
 #include "panel-types.h"
 
 BEGIN_GNOME_DECLS
 
-#define FOOBAR_WIDGET_TYPE     (foobar_widget_get_type ())
-#define FOOBAR_WIDGET(o)       (GTK_CHECK_CAST (o, FOOBAR_WIDGET_TYPE, FoobarWidget))
-#define FOOBAR_WIDGET_CLASS(k) (GTK_CHECK_CLASS_CAST (k, FOOBAR_WIDGET_TYPE, FoobarWidgetType))
-#define IS_FOOBAR_WIDGET(o)    (GTK_CHECK_TYPE (o, FOOBAR_WIDGET_TYPE))
+#define TYPE_FOOBAR_WIDGET     (foobar_widget_get_type ())
+#define FOOBAR_WIDGET(o)       (GTK_CHECK_CAST ((o), TYPE_FOOBAR_WIDGET, FoobarWidget))
+#define FOOBAR_WIDGET_CLASS(k) (GTK_CHECK_CLASS_CAST ((k), TYPE_FOOBAR_WIDGET, FoobarWidgetType))
+#define IS_FOOBAR_WIDGET(o)    (GTK_CHECK_TYPE ((o), TYPE_FOOBAR_WIDGET))
 
 typedef struct _FoobarWidget           FoobarWidget;
 typedef struct _FoobarWidgetClass      FoobarWidgetClass;
@@ -25,10 +25,18 @@ struct _FoobarWidget
 {
 	GtkWindow window;
 
+	/*< private >*/
+
 	GtkWidget *ebox;
 	GtkWidget *hbox;
 	GtkWidget *panel;
 	GtkWidget *clock_ebox;
+	GtkWidget *clock_label;
+	guint clock_timeout;
+
+	GtkWidget *programs;
+	GtkWidget *favorites;
+	GtkWidget *settings;
 
 	gboolean compliant_wm;
 	char *clock_format;
@@ -39,15 +47,21 @@ struct _FoobarWidgetClass
 	GtkWindowClass panel_class;
 };
 
-GtkType		foobar_widget_get_type		(void);
+GtkType		foobar_widget_get_type		(void) G_GNUC_CONST;
 GtkWidget *	foobar_widget_new		(void);
 
 void		foobar_widget_update_winhints	(FoobarWidget *foo);
 void		foobar_widget_redo_window	(FoobarWidget *foo);
 
+void		foobar_widget_set_clock_format	(FoobarWidget *foo,
+						 const char *format);
+
+
 gboolean	foobar_widget_exists		(void);
 gint		foobar_widget_get_height	(void);
 
+void		foobar_widget_force_menu_remake	(void);
+
 END_GNOME_DECLS
 
 #endif
