@@ -58,7 +58,8 @@ enum {
 	TARGET_DIRECTORY,
 	TARGET_COLOR,
 	TARGET_APPLET,
-	TARGET_APPLET_INTERNAL
+	TARGET_APPLET_INTERNAL,
+	TARGET_BGIMAGE
 };
 
 static GtkTargetEntry panel_drop_types[] = {
@@ -69,7 +70,8 @@ static GtkTargetEntry panel_drop_types[] = {
 	{ "application/x-panel-directory", 0, TARGET_DIRECTORY },
 	{ "application/x-panel-applet", 0, TARGET_APPLET },
 	{ "application/x-panel-applet-internal", 0, TARGET_APPLET_INTERNAL },
-	{ "application/x-color", 0, TARGET_COLOR }
+	{ "application/x-color", 0, TARGET_COLOR },
+	{ "property/bgimage",    0, TARGET_BGIMAGE }
 };
 
 static gint n_panel_drop_types = 
@@ -843,7 +845,7 @@ extract_filename (const gchar* uri)
 static void
 drop_url(PanelWidget *panel, int pos, char *url)
 {
-	char *p = g_strdup_printf("Open URL: %s",url);
+	char *p = g_strdup_printf(_("Open URL: %s"),url);
 	load_launcher_applet_from_info_url(url, p, url, "netscape.png",
 					   panel, pos, TRUE);
 	g_free(p);
@@ -852,15 +854,16 @@ drop_url(PanelWidget *panel, int pos, char *url)
 static void
 drop_menu(PanelWidget *panel, int pos, char *dir)
 {
-	int flags = MAIN_MENU_SYSTEM|MAIN_MENU_USER;
+	int flags = MAIN_MENU_SYSTEM | MAIN_MENU_USER;
+	DistributionType distribution = get_distribution_type ();
 
-	/*guess redhat menus*/
-	if(g_file_exists("/etc/X11/wmconfig"))
-		flags |= MAIN_MENU_REDHAT_SUB;
+	/*guess distribution menus*/
+	if(distribution != DISTRIBUTION_UNKNOWN)
+		flags |= MAIN_MENU_DISTRIBUTION_SUB;
 	/* Guess KDE menus */
 	if(g_file_exists(kde_menudir))
 		flags |= MAIN_MENU_KDE_SUB;
-	load_menu_applet(dir, flags, panel, pos, TRUE);
+	load_menu_applet(dir, flags, TRUE, FALSE, NULL, panel, pos, TRUE);
 }
 
 static void
@@ -876,16 +879,16 @@ drop_urilist(PanelWidget *panel, int pos, char *urilist,
 		const char *mimetype;
 		char *filename;
 
-		if(strncmp(li->data,"http:",strlen("http:"))==0 ||
-		   strncmp(li->data,"https:",strlen("https:"))==0 ||
-		   strncmp(li->data,"ftp:",strlen("ftp:"))==0 ||
-		   strncmp(li->data,"gopher:",strlen("gopher:"))==0) {
+		if(strncmp(li->data, "http:", strlen("http:")) == 0 ||
+		   strncmp(li->data, "https:", strlen("https:")) == 0 ||
+		   strncmp(li->data, "ftp:", strlen("ftp:")) == 0 ||
+		   strncmp(li->data, "gopher:", strlen("gopher:")) == 0) {
 			drop_url(panel,pos,li->data);
 			continue;
 		}
 
 		filename = extract_filename(li->data);
-		if(!filename)
+		if(filename == NULL)
 			continue;
 
 		if(stat(filename, &s) != 0) {
@@ -912,6 +915,19 @@ drop_urilist(PanelWidget *panel, int pos, char *urilist,
 	gnome_uri_list_free_strings (files);
 }
 
+static void
+drop_bgimage(PanelWidget *panel, char *bgimage)
+{
+	char *filename;
+
+	filename = extract_filename(bgimage);
+	if(filename != NULL) {
+		panel_widget_set_back_pixmap (panel, filename);
+
+		g_free(filename);
+	}
+}
+
 static void
 drop_internal_applet(PanelWidget *panel, int pos, char *applet_type)
 {
@@ -991,7 +1007,8 @@ is_this_drop_ok(GtkWidget *widget, GdkDragContext *context, guint *info,
 		if(gtk_target_list_find(panel_target_list, 
 					GPOINTER_TO_UINT(li->data),
 					&temp_info)) {
-			if(temp_info == TARGET_COLOR &&
+			if((temp_info == TARGET_COLOR ||
+			    temp_info == TARGET_BGIMAGE) &&
 			   IS_FOOBAR_WIDGET(widget))
 				return FALSE;
 			if(info) *info = temp_info;
@@ -1131,6 +1148,10 @@ drag_data_recieved_cb (GtkWidget	 *widget,
 	case TARGET_COLOR:
 		drop_color(panel, pos, (guint16 *)selection_data->data);
 		break;
+	case TARGET_BGIMAGE:
+		if( ! IS_FOOBAR_WIDGET(widget))
+			drop_bgimage(panel, (char *)selection_data->data);
+		break;
 	case TARGET_DIRECTORY:
 		drop_menu(panel, pos, (char *)selection_data->data);
 		break;
@@ -1150,7 +1171,7 @@ drag_data_recieved_cb (GtkWidget	 *widget,
 		return;
 	}
 
-	gtk_drag_finish(context,TRUE,FALSE,time);
+	gtk_drag_finish(context, TRUE, FALSE, time);
 }
 
 static void
@@ -1225,7 +1246,7 @@ drawer_orient_change_foreach(GtkWidget *w, gpointer data)
 	PanelWidget *panel = data;
 	
 	if(info->type == APPLET_DRAWER)
-		orientation_change(info,panel);
+		orientation_change(info, panel);
 }
 
 static void
